@@ -6,7 +6,7 @@
 #' @md
 #'
 #' @description ``geom_superberrorbar()`` is a geom for ggplots; it is based on 
-#'      the original geom_errorbar (and is totally compatible with it) but
+#'      the original `geom_errorbar()` (and is totally compatible with it) but
 #'      expands this geom in four different ways. First, it is possible to
 #'      decide the error bar tips `direction` which can be unidirectional, pointing to 
 #'      the "left" or to the "right" or go in "both" directions.
@@ -24,17 +24,17 @@
 #' @param stat (as usual) see geom_errorbar
 #' @param position (as usual) see geom_errorbar
 #' @param ... all additional parameters are sent to the underlying geom_path. Includes
-#'    * ``pointing`` (NEW) either "up", "down" or "both" up and down;
-#'    * ``direction`` (NEW) "left", "right" or "both" (Default is "both")
-#'    * ``tipformat`` (NEW) "single", "double" or "triple" to add additional 
+#'    * ``pointing`` either "up", "down" or "both" up and down (default is "both");
+#'    * ``direction``  "left", "right" or "both" (Default is "both")
+#'    * ``tipformat``  "single", "double" or "triple" to add additional 
 #'        marker lines to the tips (default is "single")
-#'    * ``tipgap`` (NEW) The spacing between the markers when "double" or "triple" is used (default 0.1)
-#'    * ``vcolour`` (NEW) for the vertical part of the error bar
-#'    * ``wcolour`` (NEW) if specified, for the second half of the vertical part of the error bar.
-#' @param na.rm (as usual) see geom_errorbar
-#' @param orientation (as usual) see geom_errorbar
-#' @param show.legend (as usual) see geom_errorbar
-#' @param inherit.aes (as usual) see geom_errorbar
+#'    * ``tipgap`` The spacing between the markers when "double" or "triple" is used (default 0.1)
+#'    * ``vcolour`` for the vertical part of the error bar
+#'    * ``wcolour`` if specified, for the second half of the vertical part of the error bar.
+#' @param na.rm (as usual) see `geom_errorbar()`
+#' @param orientation (as usual) see `geom_errorbar()`
+#' @param show.legend (as usual) see `geom_errorbar()`
+#' @param inherit.aes (as usual) see `geom_errorbar()`
 #'
 #' @return a layer containing error bars in a ggplot object
 #'
@@ -97,16 +97,16 @@
 #'             errorbarParams = list(direction = "left", color="purple", 
 #'                                   width = 0.2, position = position_nudge(-0.05) ),
 #'             gamma     = 0.95,
-#'             plotStyle = "line" ) + ornate
+#'             plotLayout = "line" ) + ornate
 #' plt2 <- superb( 
 #'             crange(DV.1, DV.5) ~ ., 
 #'             test, 
 #'             WSFactors = "Moment(5)",  
 #'             adjustments=list(purpose = "difference", decorrelation = "CA"), 
-#'             errorbarParams = list(direction = "right", tipgap = 0.25, tipformat = "double", 
+#'             errorbarParams = list(direction = "right", tipgap = 0.40, tipformat = "double", 
 #'                                   width = 0.2, position = position_nudge(+0.05) ),
 #'             gamma     = 0.99,
-#'             plotStyle = "line" ) + ornate 
+#'             plotLayout = "line" ) + ornate 
 #' plt3 <- superb( 
 #'             crange(DV.1, DV.5) ~ ., 
 #'             test, 
@@ -115,7 +115,7 @@
 #'             errorbarParams = list(direction = "both", tipformat = "single", pointing="up", 
 #'                                   width = 0.2, position = position_nudge(0) ),
 #'             gamma     = 0.999,
-#'             plotStyle = "line" ) + ornate 
+#'             plotLayout = "line" ) + ornate 
 #' 
 #' # transform the ggplots into "grob" so that they can be manipulated
 #' plt1 <- ggplotGrob(plt1)
@@ -151,11 +151,13 @@
 #'                            pointing = point, 
 #'                            wcolour = vcolo,  
 #'                            vcolour = "green",
+#'                            tipgap = 0.40,
 #'                            tipformat = tipfo
 #'        ), 
 #'        width = 4)
 #'
 #' @export geom_superberrorbar
+#'
 ######################################################################################
 
 
@@ -181,7 +183,7 @@ geom_superberrorbar <- function(
         data        = data,
         mapping     = mapping,
         stat        = stat,
-        geom        = GeomsuperbErrorbar,
+        geom        = GeomSuperbErrorbar,
         position    = position,
         show.legend = show.legend,
         inherit.aes = inherit.aes,
@@ -196,7 +198,7 @@ geom_superberrorbar <- function(
 # from rlang
 `%||%` <- function(x, y) {if (is.null(x)) y else x }
 
-GeomsuperbErrorbar <- ggproto("GeomsuperbErrorbar", Geom,
+GeomSuperbErrorbar <- ggproto("GeomSuperbErrorbar", Geom,
     default_aes = aes( # the parameters
         colour    = "black", 
         linewidth = 0.5, 
