@@ -31,12 +31,17 @@
 #'      (default is a normal distribution with a mean of 0 and standard deviation of 1)
 #' @param Contaminant a list providing the contaminant characteristics 
 #'      and the proportion of contaminant (default 0)
+#' @param Instrument a list providing some characteristics 
+#'      of the measurement instrument (at this time, its precision and range only)­.
 #'
 #'
-#' @return a data.frame with the simulated scores.
+#' @return a `data.frame()` with the simulated scores.
 #'
 #' @note Note that the \code{range} effect specification has been renamed
-#'    \code{extent} to avoid masking the base function \code{base::range}.
+#'    \code{extent} to avoid masking the base function \code{base::range()}.
+#'
+#' @references
+#'   \insertAllCited
 #'
 #' @examples
 #'  # Simplest example using all the default arguments: 
@@ -71,25 +76,25 @@
 #'
 #'  # This example adds an effect along the "Difficulty" factor with a slope of 15
 #'  dta <- GRD(BSFactors="Difficulty(5)", SubjectsPerGroup = 100,
-#'      Population=list(mean=50,stddev=5), 
+#'      Population=list(mean=50,stddev=15), 
 #'      Effects = list("Difficulty" = slope(15) )  )
 #'  # show the mean performance as a function of difficulty:
 #'  superb(DV ~ Difficulty, dta )
 #' 
 #'  # An example in which the moments are correlated
 #'  dta <- GRD( BSFactors = "Difficulty(2)",WSFactors = "Moment (2)", 
-#'      SubjectsPerGroup = 250,
+#'      SubjectsPerGroup = 125,
 #'      Effects = list("Difficulty" = slope(3), "Moment" = slope(1) ),
 #'      Population=list(mean=50,stddev=20,rho=0.85)
 #'  )
 #'  # the mean plot on the raw data...
 #'  superb(cbind(DV.1,DV.2) ~ Difficulty, dta, WSFactors = "Moment(2)", 
-#'      plotStyle="line",
+#'      plotLayout="line",
 #'      adjustments = list (purpose="difference") )
 #'  # ... and the mean plot on the decorrelated data; 
 #'  # because of high correlation, the error bars are markedly different
 #'  superb(cbind(DV.1,DV.2) ~ Difficulty, dta, WSFactors = "Moment(2)", 
-#'      plotStyle="line",
+#'      plotLayout="line",
 #'      adjustments = list (purpose="difference", decorrelation = "CM") )
 #'  
 #'  # This example creates a dataset in a 3 x 2 design. It has various effects,
@@ -106,11 +111,23 @@
 #'          "difficulty*gender"=custom(-300,+200,-100,0,0,0) 
 #'      ) 
 #'  )
-#'  
-#'  
+#'
+#'
+#'  # This last example creates a single group dataset,
+#'  # The instrument is assumed to return readings to 
+#'  # plus or minus 0.1 only
+#'  GRD(
+#'      SubjectsPerGroup = 10,
+#'      Population = list(mean=100,stddev=15), 
+#'      Instrument    = list(
+#'          precision = 0.1, range = c(-100,+100)
+#'      ) 
+#'  )
+#'
+#'
 #' @references
 #' \insertAllCited{} 
-#' 
+#'
 #' @importFrom Rdpack reprompt
 #' @export GRD
 #' @import stats
@@ -125,7 +142,8 @@ GRD <- function(
     WSFactors = "",
     Effects = list(),
     Population  = list(mean = 0, stddev = 1, rho = 0, scores="rnorm(1, mean = GM, sd = STDDEV)"),
-    Contaminant = list(mean = 0, stddev = 1, rho = 0, scores="rnorm(1, mean = CGM, sd = CSTDDEV)", proportion = 0)
+    Contaminant = list(mean = 0, stddev = 1, rho = 0, scores="rnorm(1, mean = CGM, sd = CSTDDEV)", proportion = 0),
+    Instrument  = list(precision = 10^(-8), range = c(-Inf,+Inf) )
 ){
     #####################################################
     # STEP 0: Load required library
@@ -137,10 +155,9 @@ GRD <- function(
     # STEP 1: Determining experimental design
     #####################################################
 
-    # initialize variables
+    # 1.1: Determining between-group factors
     BSList <- list()
     WSList <- list()
-    # determining between-group factors
     if (!(all(BSFactors==""))) {
         BSList <- grdUnpacker(BSFactors, ':', 'BS')
     }
@@ -148,39 +165,71 @@ GRD <- function(
     runDebug("GRD:1.1", "GRD:1.1: Processing BSFactors", 
         c("BSList","ngroups"),list(BSList,ngroups))
 
-    # determining repeated measures
+    # 1.2: Determining repeated measure factors
     if (!(all(WSFactors==""))) {
         unpacked <- grdUnpacker(WSFactors, ':', 'WS')
         if (any(names(unpacked) %in% names(BSList))) 
-            stop('GRD::error(1): Unique names across BSFactors and WSFactors list must be provided')
+            stop('GRD::error(1): Unique names across BSFactors and WSFactors list must be provided. Exiting...')
         WSList <- unpacked
     }
     nreplic <- prod(unlist(lapply(WSList,length)))
     runDebug("GRD:1.2", "GRD:1.2: Processing WSFactors", 
         c("WSList","nreplic"),list(WSList,nreplic))
 
-    # validating groups sizes
+    # 1.3: Validating groups sizes
     if ((length(SubjectsPerGroup)!= 1)&&(length(SubjectsPerGroup)!=ngroups)) 
-        stop('GRD::error(2): There is ',ngroups, " groups to be created but only ",length(SubjectsPerGroup), " have been defined")
+        stop('GRD::error(2): There is ',ngroups, " groups to be created but only ",length(SubjectsPerGroup), " have been defined. Exiting...")
 
-    # setting matrix size, Columns and Rows
+    # 1.4: Setting matrix size, Columns and Rows
     BSnames  <- names(BSList)
     WSnames  <- names(WSList)
-    facnames <- c(BSnames, WSnames); cols <- 2+ length(facnames) # variable "id" et "DV" ajout?e
+    facnames <- c(BSnames, WSnames)
+    if (RenameDV %in% facnames) 
+        stop('GRD::error(8): The RenameDV name is already in the within or between subject factor names. Exiting...')
+
+    # 1.5: Check that effect names are in facnames
+    if (length(Effects) > 0 ) { 
+        for (i in 1:length(Effects)) {
+            if (Effects[[i]][1] < -90) {  #slope, extent, custom
+                if (!(all(grdDepacker(names(Effects[i])) %in% facnames))) {
+                    stop('GRD::error(9): One of the effect name not in the list of factor names. Exiting...')
+                }
+            }
+        }
+    }
+    
+    # 1.6: Checking Instruments arguments
+    if (!is.numeric(Instrument$precision))
+        stop('GRD::error(11): Instrument precision not a number. Exiting...')
+    if ( Instrument$precision <0 )
+        stop('GRD::error(12): Instrument precision below zero. Exiting...')
+    if (length(Instrument$range)!=2)
+        stop('GRD::error(13): Instrument range not two numbers')
+    if ((Instrument$range[1]!=-Inf)&(!is.numeric(Instrument$range[1])))
+        stop('GRD::error(14): Instrument lower range not a number or -Inf. Exiting...')
+    if ((Instrument$range[2] != +Inf)&(!is.numeric(Instrument$range[2])))
+        stop('GRD::error(15): Instrument upper range not a number or +Inf. Exiting...')
+    if (Instrument$range[1] >= Instrument$range[2])
+        stop('GRD::error(16): Instrument lower range greater than upper range. Exiting...')
+
+    # 1.7: Set subject number and number of rows
+    cols <- 2+ length(facnames) # variables "id" et "DV" ajoutées
     subj <- if(length(SubjectsPerGroup)==1) {
         SubjectsPerGroup * ngroups
     } else {
         sum(SubjectsPerGroup) 
     }
     rows = subj * nreplic
-    runDebug("GRD:1.3", "GRD:1.3: Processing matrix size", 
-        c("BSnames","WSnames","facnames","cols","rows","subj"   ),
-        list(BSnames,WSnames,facnames,cols,rows,subj))
-
+    
+    # 1.8: Show design if not inhibited
     if ('summary' %in% getOption("superb.feedback") ) {
         grdShowDesign(BSList, WSList, ngroups, nreplic, subj, SubjectsPerGroup)
     }
 
+    runDebug("GRD:1.3", "GRD:1.3: Processing matrix size", 
+        c("BSnames","WSnames","facnames","cols","rows","subj"   ),
+        list(BSnames,WSnames,facnames,cols,rows,subj))
+
   
     #####################################################
     # STEP 2: Generating the data matrix long
@@ -208,7 +257,8 @@ GRD <- function(
 
     # set repeated measure identifiers
     if(length(WSList)>0) {
-        design <- expand.grid(WSList)
+        # print(WSList)
+        design <- reversed.expand.grid(WSList)
         for (i in 1:length(WSList)) {
             data[,1+length(BSList)+i] = unlist(lapply(design[,i],rep,times=subj))
         }
@@ -246,12 +296,12 @@ GRD <- function(
         if(length(GM)==1) { 
             GM = rep(GM, nreplic)
         } else if (length(GM) != nreplic) {
-            stop(paste("GRD::error(4): The mean is a vector of inadequate length for",nreplic,"replications"))
+            stop(paste("GRD::error(4): The mean is a vector of inadequate length for",nreplic,"replications. Exiting..."))
         } 
         if(length(STDDEV)==1) {
             SIGMA = diag(nreplic) * STDDEV*STDDEV + (1-diag(nreplic))* STDDEV*STDDEV * RHO
         } else if (length(STDDEV)!=nreplic) {
-            stop(paste("GRD::error(5): The standard deviation is a vector of inadequate length for",nreplic,"replications"))
+            stop(paste("GRD::error(5): The standard deviation is a vector of inadequate length for",nreplic,"replications. Exiting..."))
         } else {
             SIGMA = diag(nreplic) * STDDEV*STDDEV + (1-diag(nreplic))* outer(STDDEV,STDDEV) * RHO        
         }
@@ -264,12 +314,12 @@ GRD <- function(
         if(length(CGM)==1) { 
             CGM = rep(CGM, nreplic)
         } else if (length(CGM) != nreplic) {
-            stop(paste("GRD::error(6): The mean is a vector of inadequate length for",nreplic,"replications"))
+            stop(paste("GRD::error(6): The mean is a vector of inadequate length for",nreplic,"replications. Exiting..."))
         } 
         if(length(CSTDDEV)==1) {
             CSIGMA = diag(nreplic) * CSTDDEV*CSTDDEV + (1-diag(nreplic))* CSTDDEV*CSTDDEV * CRHO
         } else if (length(CSTDDEV)!=nreplic) {
-            stop(paste("GRD::error(7): The standard deviation is a vector of inadequate length for",nreplic,"replications"))
+            stop(paste("GRD::error(7): The standard deviation is a vector of inadequate length for",nreplic,"replications. Exiting..."))
         } else {
             CSIGMA = diag(nreplic) * CSTDDEV*CSTDDEV + (1-diag(nreplic))* outer(CSTDDEV,CSTDDEV) * CRHO
         }
@@ -357,7 +407,19 @@ GRD <- function(
 
   
     #####################################################
-    # STEP 6: Let's clean the place
+    # STEP 6: Apply the instrument's characteristics, if any
+    #####################################################
+    # Round the numbers
+    if ( is.numeric(Instrument$precision) ) {
+        data$DV <- grdROUND(data$DV, Instrument$precision)
+    }
+    if (is.numeric(Instrument$range[1]))
+        data$DV[ data$DV < Instrument$range[1] ] <- Instrument$range[1]
+    if (is.numeric(Instrument$range[2]))
+        data$DV[ data$DV > Instrument$range[2] ] <- Instrument$range[2]
+
+    #####################################################
+    # STEP 7: Let's clean the place
     #####################################################
     # Rename DV with its name
     colnames(data)[colnames(data) == "DV"] <- gsub("[[:space:]]", "", RenameDV)
@@ -369,7 +431,7 @@ GRD <- function(
   
   
     #####################################################
-    # STEP 7: All done
+    # STEP 8: All done
     #####################################################
     return(data)
 }
@@ -420,9 +482,16 @@ Rexpression <- function(str)   { c("-96", paste(c(str),collapse="") ) }
 
 
 ##################################################################   
-# Subsidiary private functions: grdMakeEffect; grdL2W; grdDepacker; grdUnpacker;
+# Subsidiary functions: grdROUND, grdMakeEffect; grdL2W; 
+#                       grdDepacker; grdUnpacker;
 ##################################################################   
 
+grdROUND <- function(x, k) {
+    p <- 10^(floor(log10(k)))
+#    print(p)
+    x - x %% p
+}
+
 grdMakeEffect <- function (fnumber, name, details, WBSList, data, allfactors ) {
 
     if (details[1] == "-96") {
@@ -558,7 +627,7 @@ grdUnpacker = function(string, sep_across, defaultfactorname) {
 
 
 ##################################################################   
-# small private functions: grdShowDesign;
+# small private functions: grdShowDesign; reversed.expand.grid
 ##################################################################   
 
 grdShowDesign <- function(BSList,WSList,ngroups,nreplic,subj,SubjectsPerGroup) {
@@ -585,7 +654,45 @@ grdShowDesign <- function(BSList,WSList,ngroups,nreplic,subj,SubjectsPerGroup) {
     cat("\n",paste(rep('-',60),collapse=""),"\n")
 }
 
-    
+
+# expand.grid running through first factor slowliest
+# it is the opposite of expand.grid.
+reversed.expand.grid <- function (...) {
+    # 1. input validation
+    nargs <- length(list(...))
+    if ((!nargs) | (nargs == 0L) ) {
+        #print("zero argument ou rien du tout")
+        return(as.data.frame(list()))
+    } else if (nargs == 1L && is.list(list(...)[[1]])) {
+        #print("un argument")
+        inputs <- list(...)[[1]]
+    } else if (is.list(list(...))) {
+        #print("plusieurs arguments")
+        inputs <- list(...)
+    } else
+        stop("GRD::error: Something wicked in reversed.expand.grid. Exiting...")
+
+    # 2. preparation
+    n.levels <- vapply(inputs, length, integer(1))
+    n.rows   <- prod(n.levels)
+    n.each   <- n.rows / cumprod(n.levels)
+    n.times  <- n.rows / n.each / n.levels
+    # 3. generation
+    df <- mapply(FUN = \(x, y, z) {rep(rep(x, each = y), z) }, 
+                x = inputs, 
+                y = n.each, 
+                z = n.times, 
+                SIMPLIFY = FALSE)
+    return(data.frame(df))
+}
+
+# Quick tests are in test_that:
+# reversed.expand.grid()
+# reversed.expand.grid(a=1:2, b=1:3)
+# reversed.expand.grid( list(a=1:2, b=1:3) )
+
+
+  
 ##################################################################   
-# End of grd.
+# End of GRD.
 ##################################################################   
