@@ -3,10 +3,10 @@
 #'
 #' @md
 #'
-#' @description The function ``superbPlot()`` plots standard error or confidence interval for various  
+#' @description The function `superbPlot()` plots standard error or confidence interval for various  
 #'      descriptive statistics under various designs, sampling schemes, population size and purposes,
 #'      according to the ``suberb`` framework. See \insertCite{cgh21}{superb} for more.
-#'      Note that this function has been superseded by ``superb()``.
+#'      Note that this function has been superseded by `superb()`.
 #'
 #' @param data Dataframe in wide format
 #'
@@ -15,30 +15,31 @@
 #' @param WSDesign the within-subject design if not a full factorial design (default "fullfactorial")
 #' @param variables The dependent variable(s) as strings
 #'
-#' @param statistic The summary statistic function to use as a string
+#' @param statistic The summary statistic function to use as a string. 
 #' @param errorbar The function that computes the error bar. Should be "CI" or "SE" or 
 #'      any function name if you defined a custom function. Default to "CI"
-#' @param gamma The coverage factor; necessary when ``errorbar == "CI"``. Default is 0.95.
+#' @param gamma The coverage factor; necessary when `errorbar == "CI"`. Default is 0.95.
 #' @param factorOrder Order of factors as shown in the graph (in that order: x axis,
 #'       groups, horizontal panels, vertical panels)
 #'
 #' @param adjustments List of adjustments as described below.
-#'      Default is ``adjustments = list(purpose = "single", popSize = Inf, decorrelation = "none",
-#'              samplingDesign = "SRS")``
+#'      Default is `adjustments = list(purpose = "single", popSize = Inf, decorrelation = "none",
+#'              samplingDesign = "SRS")`
 #' @param clusterColumn used in conjunction with samplingDesign = "CRS", indicates which column 
 #'    contains the cluster membership
 #'
 #' @param showPlot Defaults to TRUE. Set to FALSE if you want the output to be the summary 
 #'     statistics and intervals.
-#' @param plotStyle The type of object to plot on the graph. See full list below.
-#'      Defaults to "bar".
+#' @param plotStyle `r lifecycle::badge("deprecated")`
+#' @param plotLayout The layers to plot on the graph. See full list below.
+#'      Defaults to "line".
 #'
 #' @param preprocessfct  is a transform (or vector of) to be performed first on data matrix of each group
 #' @param postprocessfct is a transform (or vector of)
 #'
 #' @param ...  In addition to the parameters above, superbPlot also accept a number of 
 #'  optional arguments that will be transmitted to the plotting function, such as
-#'  pointParams (a list of g`lot2 parameters to input inside geoms; see ?geom_bar2) and
+#'  pointParams (a list of gglot2 parameters to input inside geoms; see ?geom_bar2) and
 #'  errorbarParams (a list of ggplot2 parameters for geom_errorbar; see ?geom_errorbar)
 #'
 #'
@@ -74,14 +75,17 @@
 #'
 #' but refer to `superb()` for a documentation that will be kept up do date.
 #'
+#' EXPERIMENTAL: if both the statistic
+#'          function and its related errorbar function are in a different namespace, you may use the 
+#'          notation "namespace::funcname" in the `statistic` argument. The same namespace will be used
+#'          for the errorbar function.
+#'
 #' @md
 #'
 #' @references
 #' \insertAllCited{}
 #'
 #' @examples
-#' ######################################################################
-#'
 #' # Basic example using a built-in dataframe as data. 
 #' # By default, the mean is computed and the error bar are 95% confidence intervals
 #' superbPlot(ToothGrowth, BSFactors = c("dose", "supp"), 
@@ -108,7 +112,7 @@
 #' xlab("Dose") + ylab("Tooth Growth") +
 #' theme_bw()
 #'
-#' ######################################################################
+#' 
 #'
 #' # The following examples are based on repeated measures
 #' library(gridExtra)
@@ -139,7 +143,7 @@
 #' # The error bars shortened as the correlation is substantial (r = .795).
 #' 
 #' 
-#' ######################################################################
+#' 
 #' 
 #' # Another example: The Orange data
 #' data(Orange)
@@ -169,7 +173,7 @@
 #' # You can present both plots side-by-side
 #' grid.arrange(p1, p2, ncol=2)
 #'
-#' ######################################################################
+#' 
 #' 
 ######################################################################################
 #'
@@ -198,7 +202,8 @@ superbPlot <- function(data,
         samplingDesign = "SRS"       # is "SRS" or "CRS" (in which case use clusterColumn)
     ),
     showPlot      = TRUE,            # show a plot or else summary statistics
-    plotStyle     = "bar",           # type of plot (so far, bar, line, point, pointjitter and pointjitterviolin
+    plotStyle     = NULL,            # type of plot (so far, bar, line, point, pointjitter and pointjitterviolin
+    plotLayout    = "line",          # type of plot (so far, bar, line, point, pointjitter and pointjitterviolin
     preprocessfct = NULL,            # run preprocessing on the matrix
     postprocessfct= NULL,            # run post-processing on the matrix
     clusterColumn = "",              # if samplineScheme = CRS
@@ -217,7 +222,7 @@ superbPlot <- function(data,
     # 1.0: are the data actually data!
 	data <- as.data.frame(data) # coerce to data.frame if tibble or compatible
     if(!(is.data.frame(data)))
-            stop("superb::ERROR: data is not a data.frame or similar data structure. Exiting...")
+            stop("superb::ERROR(1): data is not a data.frame or similar data structure. Exiting...")
 
     # 1.1: missing adjustements
     if(is.null(adjustments$purpose))        {adjustments$purpose        <- "single"}
@@ -227,38 +232,38 @@ superbPlot <- function(data,
 
     # 1.2: unknown adjustments listed
     if (!all(names(adjustments) %in% c("purpose","popSize","decorrelation","samplingDesign")))
-            stop("superb::ERROR: one of the adjustment is unknown. Exiting...")
+            stop("superb::ERROR(2): one of the adjustment is unknown. Exiting...")
 
     # 1.3: invalid choice in a list of possible choices
     if (is.character(adjustments$popSize)||!(all(adjustments$popSize >0)))  
-            stop("superb::ERROR: popSize should be a positive number or Inf (or a list of these). Exiting...")
+            stop("superb::ERROR(3): popSize should be a positive number or Inf (or a list of these). Exiting...")
     if (!(adjustments$purpose %in% c("single","difference","tryon"))) 
-            stop("superb::ERROR: Invalid purpose. Did you mean 'difference'? Exiting...")
+            stop("superb::ERROR(4): Invalid purpose. Did you mean 'difference'? Exiting...")
     if (!(substr(adjustments$decorrelation,1,2) %in% c("no","CM","LM","CA","UA","LD"))) 
-            stop("superb::ERROR: Invalid decorrelation method. Did you mean 'CM'? Exiting...")
+            stop("superb::ERROR(5): Invalid decorrelation method. Did you mean 'CM'? Exiting...")
     if (substr(adjustments$decorrelation,1,2) == "LD") {
             radius <- suppressWarnings(as.integer(substr(adjustments$decorrelation, 3, 100)))
             if ((is.na(radius))||(radius<1))
-                stop("superb::ERROR: radius given to LD not an integer or is smaller than 1. Exiting...")
+                stop("superb::ERROR(6): radius given to LD not an integer or is smaller than 1. Exiting...")
     }
     if (!(adjustments$samplingDesign %in% c("SRS","CRS"))) 
-            stop("superb::ERROR: Invalid samplingDesign. Did you mean 'SRS'? Exiting...")
+            stop("superb::ERROR(7): Invalid samplingDesign. Did you mean 'SRS'? Exiting...")
 
     # 1.4a: innapropriate choice for between-subject specifications
     bsLevels <- dim(unique(data[BSFactors]))[1]
     if (!(length(adjustments$popSize) %in% c(1,bsLevels))) 
-            stop("superb::ERROR: popSize is a list whose length does not match the number of groups. Exiting...")
+        stop("superb::ERROR(8): popSize is a list whose length does not match the number of groups. Exiting...")
     
     # 1.4b: invalid within-subject factors
     if (any(unlist(gregexpr("\\w\\((\\d+)\\)", WSFactors))== -1))
-            stop("superb::ERROR: One of the repeated-measure factor not properly formed 'name(nlevel)'. Exiting...")
+        stop("superb::ERROR(9): One of the repeated-measure factor not properly formed 'name(nlevel)'. Exiting...")
     wsMissing <- "DummyWithinSubjectFactor"
     wsLevels <- c(1)
     if (is.null(WSFactors)) {
         WSFactors <- wsMissing
     } else {
         for (i in 1:length(WSFactors)) {
-            wsLevels[i] <- as.integer(unlist(strsplit(WSFactors[i], '[()]'))[2]) 
+            wsLevels[i]  <- as.integer(unlist(strsplit(WSFactors[i], '[()]'))[2]) 
             WSFactors[i] <-            unlist(strsplit(WSFactors[i], '[()]'))[1]
         }
     }
@@ -269,48 +274,60 @@ superbPlot <- function(data,
         factorOrder <- c(WSFactors, BSFactors)
         if (('design' %in% getOption("superb.feedback") ) & (length(factorOrder[factorOrder != wsMissing])) > 1)  
                 message(paste("superb::FYI: The variables will be plotted in that order: ",
-                          paste(factorOrder[factorOrder != wsMissing],collapse=", "),
-                          " (use factorOrder to change).", sep=""))
+                              paste(factorOrder[factorOrder != wsMissing],collapse=", "),
+                              " (use factorOrder to change).", sep=""))
     }
 
     # 1.4d: checking WSFactors based on WSDesign
     if (all(WSDesign == "fullfactorial")) {
         if (!(length(variables) == wslevel)) 
-                stop("superb::ERROR: The number of levels of the within-subject level(s) does not match the number of variables. Exiting...")
+                stop("superb::ERROR(10): The number of levels of the within-subject level(s) does not match the number of variables. Exiting...")
         if ((wslevel == 1)&&(!(adjustments$decorrelation == "none"))) 
-                stop("superb::ERROR: Decorrelation is not to be used when there is no within-subject factors. Exiting...")
+                stop("superb::ERROR(11): Decorrelation is not to be used when there is no within-subject factors. Exiting...")
     } else {
         if (!is.list(WSDesign) )
-                    stop("superb::ERROR: the WSdesign is not 'fullfactorial' (default) or a list. Exiting...")
+                    stop("superb::ERROR(12): the WSdesign is not 'fullfactorial' (default) or a list. Exiting...")
         if (length(WSDesign) != length(variables))
-                    stop("superb::ERROR: the WSDesign list is not of the same length as the variable vector. Exiting...")
+                    stop("superb::ERROR(13): the WSDesign list is not of the same length as the variable vector. Exiting...")
         if (!all(lapply(WSDesign, length)==length(WSFactors)))
-                    stop("superb::ERROR: the WSDesign does not contain vectors of factor levels, one per factor. Exiting...")
+                    stop("superb::ERROR(14): the WSDesign does not contain vectors of factor levels, one per factor. Exiting...")
     }
 
     # 1.5: invalid column names where column names must be listed
     if (!(all(variables %in% names(data)))) 
-            stop("superb::ERROR: One of the variable column is not found in data. Exiting...")
+            stop("superb::ERROR(15): One of the variable column is not found in data. Exiting...")
     if (!(all(BSFactors %in% names(data)))) 
-            stop("superb::ERROR: One of the BSFactors column is not found in data. Exiting...")
+            stop("superb::ERROR(16): One of the BSFactors column is not found in data. Exiting...")
 
-    # 1.6: invalid inputs
+    # 1.6: invalid inputs to factorOrder, gamma or showPlot
     if (length(factorOrder[factorOrder != wsMissing] ) > 4)
-            stop("superb::ERROR: Too many factors named on factorOrder. Maximum 4. Exiting...")
+            stop("superb::ERROR(17): Too many factors named on factorOrder. Maximum 4. Exiting...")
     if (length(factorOrder[factorOrder != wsMissing]) < length(WSFactors[WSFactors != wsMissing]) + length(BSFactors)) 
-            stop("superb::ERROR: Too few factors named on factorOrder. Exiting...")
+            stop("superb::ERROR(18): Too few factors named on factorOrder. Exiting...")
     if ((gamma[1] <0)||(gamma[1]>1))
-            stop("superb::ERROR: gamma is not within 0 and 1. Exiting...")
+            stop("superb::ERROR(19): gamma is not within 0 and 1. Exiting...")
     if (!is.logical(showPlot))
-            stop("superb::ERROR: showPlot must be TRUE or FALSE. Exiting...")
+            stop("superb::ERROR(20): showPlot must be TRUE or FALSE. Exiting...")
 
     # 1.7: align levels and corresponding variables
-    weird        <-"+!+" # to make sure that these characters are not in the column names
+    weird        <-"+!+" # should make sure that these characters are not in the column names
     if (all(WSDesign == "fullfactorial")) {
-        combinaisons <- expand.grid(lapply(wsLevels,seq))
+        # the within-subject factors are converted to numbers...
+        combinaisons <- expand.grid(lapply(wsLevels, seq))
+        names(combinaisons) <- WSFactors
+        combinaisons <- combinaisons[do.call(order, combinaisons[WSFactors]),,drop=FALSE]
     } else {
-        combinaisons <- data.frame(matrix(as.integer(unlist(WSDesign)),nrow=length(WSDesign), byrow = TRUE))
+        numbers_only <- function(x) suppressWarnings(!is.na(as.numeric(as.character(x))))
+        combinaisons <- data.frame(t(data.frame(WSDesign)))
+        for (i in names(combinaisons)) {
+            if (all(numbers_only(combinaisons[[i]])))
+                combinaisons[[i]] <- as.numeric(combinaisons[[i]])
+            else
+                combinaisons[[i]] <- as.numeric(factor(combinaisons[[i]]))      
+        }
+        names(combinaisons) <- WSFactors
     }
+
     newnames     <- paste("DV", apply(combinaisons,1,paste,collapse=weird) ,sep=weird)
     design       <- cbind(combinaisons, variables, newnames)
     colnames(design)[1:length(WSFactors)] <- WSFactors
@@ -322,29 +339,98 @@ superbPlot <- function(data,
         message(temp) 
     }
 
-    # 1.8: invalid functions 
-    widthfct <- paste(errorbar, statistic, sep = ".")
-    if (errorbar == "none") { # create a fake function
-        eval(parse(text=paste(widthfct, "<-function(X) 0",sep="")), envir = globalenv())
-    }
-    if ( !(is.stat.function(statistic)) )
-            stop("superb::ERROR: The function ", statistic, " is not a known descriptive statistic function. Exiting...")
-    if ( !(is.errorbar.function(widthfct)) )
-            stop("superb::ERROR: The function ", widthfct, " is not a known function for error bars. Exiting...")
-    pltfct <- paste("superbPlot", plotStyle, sep = ".")
-    if ( !(is.superbPlot.function(pltfct)) )
-            stop("superb::ERROR: The function ", pltfct, " is not a known function for making plots with superbPlot. Exiting...")
+    # 1.8: testing that these arguments are valid strings.
+    if (!(is.single.string(statistic))) 
+        stop("superb::ERROR(26): Argument `statistic` must be a quoted string. Exiting...")
+    if (!(is.single.string(errorbar))) 
+        stop("superb::ERROR(27): Argument `errorbar` must be a quoted string. Exiting...")
+    if (!(is.single.string(plotLayout))) 
+        stop("superb::ERROR(28): Argument `plotLayout` must be a quoted string. Exiting...")
 
-    # 1.9: if cluster randomized sampling, check that column cluster is set
+
+    ###############################################################
+    ##### EXPERIMENTAL: segment function from namespace if provided
+    ###############################################################
+    package1  <- package2 <- NULL
+    statfunc <- strsplit(statistic, "::")[[1]]
+    if (length(statfunc) == 2) {
+        package1  <- statfunc[1]  # before ::
+        statfunc <- statfunc[2]
+        if ('experimental' %in% getOption("superb.feedback")) 
+            message("superb::EXPERIMENTAL(1): statistic given with namespace ", package1, "::", statfunc)
+    }
+    widthfunc <- strsplit(errorbar, "::")[[1]]
+    if (length(widthfunc) == 2) {
+        package2  <- widthfunc[1] # before ::
+        errorbar  <- widthfunc[2]
+        if ('experimental' %in% getOption("superb.feedback")) 
+            message("superb::EXPERIMENTAL(2): errorbar given with namespace ",package2, "::", errorbar)
+    }
+    # if both have a namespace, they must match
+    if ( (!is.null(package1)) & (!is.null(package2)) ) {
+        if (package1 != package2 ) message("superb::WARNING(1): The namespace given to `errorbar` does not match the namespace given to `statistic`. Ignoring...")
+    }
+
+    # drop in globalenv() the summary statistic function
+    enviro = "globalenv()"
+    if (length(package1) > 0) { enviro = paste("asNamespace('",package1,"')", sep="") } 
+
+    f1 <- paste("superbSTATISTIC <- function(...) {do.call('",statfunc,"', list(...), envir = ",enviro,")}", sep="")
+    #print(f1)
+    eval(parse(text=f1), envir = globalenv() )
+
+    if (has.init.function(statistic)) {
+        f2 <- paste("init.superbSTATISTIC <- function(...) {do.call('init.",statfunc,"', list(...), envir = ",enviro,")}", sep="")
+    #    print(f2)
+        eval(parse(text=f2), envir = globalenv() )
+    }
+
+    widthfct <- paste(errorbar, statfunc, sep = ".")
+    if (errorbar == "none") { # create a fake function
+        #old instruction to delete
+        eval(parse(text=paste(widthfct, "<-function(X) 0", sep="")), envir = globalenv())
+        # new instruction
+        f3 <- paste("superbERRORBAR  <- function(x) {0}", sep="")
+    } else {
+        if (is.gamma.required(paste( c(package1,widthfct), collapse="::"))) {
+            f3 <- paste("superbERRORBAR  <- function(..., gamma = 0.95) {do.call('",widthfct,"', list(..., gamma = gamma), envir = ",enviro,")}",sep="")    
+        } else {
+            f3 <- paste("superbERRORBAR  <- function(...) {do.call('",widthfct,"', list(...), envir = ",enviro,")}",sep="")
+        }
+    }
+    #print(f3)
+    eval(parse(text=f3), envir = globalenv() )
+    ###############################################################
+    ##### END EXPERIMENTAL
+    ###############################################################
+
+
+
+    # 1.9a: testing valid statistic functions
+    if ( !(is.stat.function("superbSTATISTIC")) )
+            stop("superb::ERROR(21): The function ", statistic, " is not a known descriptive statistic function. Exiting...")
+    if ( !(is.errorbar.function("superbERRORBAR")) )
+            stop("superb::ERROR(22): The function ", widthfct, " is not a known function for error bars. Exiting...")
+
+    # 1.9b: testing valid plot function
+    if (!is.null(plotStyle)) {
+        message("superb::DEPRECATED(1): The argument `plotStyle` is deprecated; favor the argument `plotLayout`. Continuing...")
+        plotLayout <- plotStyle
+    }
+    pltfct <- paste("superbPlot", plotLayout, sep = ".")
+    if ( !(is.superbPlot.function(pltfct)) )
+            stop("superb::ERROR(23): The function ", pltfct, " is not a known function for making plots with superbPlot. Exiting...")
+
+    # 1.10: if cluster randomized sampling, check that column cluster is set
     if (adjustments$samplingDesign == "CRS") {
         # make sure that column cluster is defined.
         if(!(clusterColumn %in% names(data))) 
-            stop("superb::ERROR: With samplingDesign = \"CRS\", you must specify a valid column with ClusterColumn. Exiting...")
+            stop("superb::ERROR(24): With samplingDesign = \"CRS\", you must specify a valid column with ClusterColumn. Exiting...")
     }
 
-    # 1.10: is there missing data in the scores?
+    # 1.11: is there missing data in the scores?
     if (any(is.na(data[,variables])) ) {
-        message("superb::WARNING: There are misssing data in your dependent variable(s).\n\tsuperb may show empty summaries... consult help(measuresWithMissingData)")
+        message("superb::WARNING(2): There are misssing data in your dependent variable(s).\n\tsuperb may show empty summaries... consult help(measuresWithMissingData)")
     }
 
     # We're clear to go!
@@ -427,11 +513,11 @@ superbPlot <- function(data,
     }
 
     # if the function has an initializer, run it on the long-format data
-    if (has.init.function(statistic)) {
-        iname = paste("init",statistic, sep=".")
+    if (has.init.function("superbSTATISTIC")) {
+        iname = paste("init",statfunc, sep=".")
         if (!("none" %in% getOption("superb.feedback")))
             message("superb::FYI: Running initializer ", iname)
-        do.call(iname, list(data.untransformed.long) )
+        do.call("init.superbSTATISTIC", list(data.untransformed.long) )
     }
 
     runDebug("superb.3", "End of Step 3: Reformat data frame into long format", 
@@ -444,14 +530,14 @@ superbPlot <- function(data,
 
     aggregatefct <- function(subsetOfData) { 
         params1 <- list( subsetOfData$DV  )
-        if (is.gamma.required(widthfct)) {
+        if (is.gamma.required("superbERRORBAR")) {
             paramsV <- list( subsetOfData$DV, gamma = gamma )
         } else {
             paramsV <- list( subsetOfData$DV  )
         }
-        center <- do.call(statistic, params1)
-        limits <- do.call(widthfct, paramsV)
-        if (is.interval.function(widthfct)) {
+        center <- do.call("superbSTATISTIC", params1)
+        limits <- do.call("superbERRORBAR", paramsV)
+        if (is.interval.function("superbERRORBAR")) {
             lowerwidth <- ( min(limits) - center)
             upperwidth <- ( max(limits) - center ) 
         } else {
@@ -550,10 +636,12 @@ superbPlot <- function(data,
                 out <- split(data[,var], crit )
                 # 2024.05.30: exlude empty conditions
                 out <- out[lengths(out)>1]
-                p   <- stats::bartlett.test(out)$p.value
-                ps  <- c(ps, p)
+                if (length(out) > 1) {
+                    p   <- stats::bartlett.test(out)$p.value
+                    ps  <- c(ps, p)
+                }
             }
-            if (any(p < .01)) 
+            if (any(ps < .01)) 
                 message("superb::ADVICE: Some of the groups' variances are heterogeneous. Consider using purpose=\"tryon\"." )
         }
 
@@ -685,9 +773,7 @@ gA <- function(w, mu, dim) {
 meanLocalCorrelation <- function(X, cols, w) {
     mat <- mycor( X[cols] )
     nrw <- dim(mat)[2]
-    sapply( 1:nrw, 
-            \(i) sum(mat[i,] * gA(w,i,nrw) )
-    )
+    sapply( 1:nrw, \(i) sum(mat[i,] * gA(w,i,nrw) ) )
 }
 # that simple!
 
