@@ -2,6 +2,7 @@
 cat("this will be hidden; use for general initializations.\n")
 library(superb)
 library(ggplot2)
+options( "superb.feedback" = c('none') )
 
 ## -----------------------------------------------------------------------------
 #Motivation data for 15 participants over three weeks in wide format:
@@ -27,14 +28,14 @@ dta <- matrix( c(
 colnames(dta) <- c("Week 1", "Week 2", "Week 3")
 dta           <- as.data.frame(dta)
 
-## ----message=FALSE, echo=FALSE, fig.height=3, fig.width=4, fig.cap="**Figure 1**. Mean scores along with 95% confidence interval per week for a program to stop smoking."----
+## ----message=FALSE, echo=FALSE, fig.alt="mean+-95%CI", fig.height=3, fig.width=4, fig.cap="**Figure 1**. Mean scores along with 95% confidence interval per week for a program to stop smoking."----
 superb(
     cbind(`Week 1`, `Week 2`, `Week 3`) ~ ., 
     dta, 
     WSFactors = "Moment(3)",
     statistic = "mean", errorbar = "CI",
     adjustments = list(purpose = "single", decorrelation = "none"),
-    plotStyle="line",
+    plotLayout = "line",
     errorbarParams = list(width = .2)
 ) + 
 coord_cartesian( ylim = c(50,100) ) +
@@ -49,17 +50,17 @@ superb(
     dta, 
     WSFactors = "Moment(3)",
     adjustments = list(purpose = "difference"),
-    plotStyle="line"
-    )
+    plotLayout = "line"
+)
 
-## ----message=FALSE, echo=FALSE, fig.height=3, fig.width=4, fig.cap="**Figure 2**. Mean scores along with difference-adjusted 95% confidence interval per week for a program to stop smoking."----
+## ----message=FALSE, echo=FALSE, fig.alt="mean+-95%CI", fig.height=3, fig.width=4, fig.cap="**Figure 2**. Mean scores along with difference-adjusted 95% confidence interval per week for a program to stop smoking."----
 superb(
     cbind(`Week 1`, `Week 2`, `Week 3`) ~ .,
     dta, 
     WSFactors = "Moment(3)",
     statistic = "mean", errorbar = "CI",
     adjustments = list(purpose = "difference"),
-    plotStyle="line",
+    plotLayout = "line",
     errorbarParams = list(width = .2)
 ) + 
 coord_cartesian( ylim = c(50,100) ) +
@@ -71,14 +72,14 @@ scale_x_discrete(labels=c("1" = "Week 1", "2" = "Week 2", "3"="Week 3"))
 ## -----------------------------------------------------------------------------
 head(dta)
 
-## ----message=FALSE, echo=TRUE, fig.height=3, fig.width=4, results='hide', fig.show='hide'----
+## ----message=FALSE, echo=TRUE, fig.alt="mean+-95%CI", fig.height=3, fig.width=4, results='hide', fig.show='hide'----
 superb(
     cbind(`Week 1`, `Week 2`, `Week 3`) ~ .,
     dta, 
     WSFactors = "Moment(3)",
     statistic = "mean", errorbar = "CI",
     adjustments = list(purpose = "difference"),
-    plotStyle="line"
+    plotLayout = "line"
 ) + 
 coord_cartesian( ylim = c(50,100) ) +
 ylab("Mean +- 95% CI") +
@@ -86,14 +87,14 @@ labs(title="Difference-adjusted\n95% confidence interval")+
 theme_gray(base_size=10) +
 scale_x_discrete(labels=c("1" = "Week 1", "2" = "Week 2", "3"="Week 3"))
 
-## ----message=TRUE, echo=TRUE, fig.height=3, fig.width=4-----------------------
+## ----message=TRUE, echo=TRUE, fig.alt="mean+-95%CI", fig.height=3, fig.width=4----
 superb(
     cbind(`Week 1`, `Week 2`, `Week 3`) ~ .,
     dta, 
     WSFactors = "Moment(3)",
     statistic = "mean", errorbar = "CI",
     adjustments = list(purpose = "difference", decorrelation = "CM"), #new!
-    plotStyle="line",
+    plotLayout = "line",
     errorbarParams = list(width = .2)
 ) + 
 coord_cartesian( ylim = c(50,100) ) +
@@ -105,7 +106,7 @@ scale_x_discrete(labels=c("1" = "Week 1", "2" = "Week 2", "3"="Week 3"))
 ## ----echo = FALSE-------------------------------------------------------------
 options(superb.feedback = 'none')
 
-## ----message=FALSE, echo=TRUE , results='hide', fig.height=3, fig.width=4-----
+## ----message=FALSE, echo=TRUE , fig.alt="mean+-95%CI", results='hide', fig.height=3, fig.width=4----
 # add (ficticious) cluster membership for each participant in the column "cluster"
 dta$cluster <- sort(rep(1:5, 3))
 
@@ -115,7 +116,7 @@ superb(
     WSFactors = "Moment(3)",
     adjustments = list(purpose = "difference", decorrelation = "CM",
                        samplingDesign = "CRS", popSize = 100),        #new!
-    plotStyle = "line",
+    plotLayout = "line",
     clusterColumn = "cluster",  # identify the column containing cluster membership
     errorbarParams = list(width = .2)
 ) + 
