@@ -56,7 +56,7 @@ superb(
 					purpose = "difference", 
 					decorrelation = "CA"    ## NEW! use a decorrelation technique
 	), 
-	plotStyle   = "line" )
+	plotLayout  = "line" )
 
 ## ----message=FALSE, warning=FALSE, echo=TRUE, fig.width = 4, fig.cap="**Figure 3b**. Means and 95% confidence intervals on raw data (left) and on decorrelated data (right)"----
 options(superb.feedback = 'none') # shut down 'warnings' and 'design' interpretation messages
@@ -68,7 +68,7 @@ plt2a <- superb(
         dataFigure2, 
         WSFactors    = "Moment(2)", 
         adjustments = list(purpose = "difference"), 
-        plotStyle   = "line" ) + 
+        plotLayout  = "line" ) + 
     xlab("Group") + ylab("Score") + 
     labs(title="Difference-adjusted\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) +
@@ -79,7 +79,7 @@ plt2b <- superb(
         dataFigure2, 
         WSFactors    = "Moment(2)", 
         adjustments = list(purpose = "difference", decorrelation = "CA"),  #only difference
-        plotStyle   = "line" ) + 
+        plotLayout  = "line" ) + 
     xlab("Group") + ylab("Score") + 
     labs(title="Correlation and difference-adjusted\n95% confidence intervals") +
     coord_cartesian( ylim = c(85,115) ) + 
@@ -106,10 +106,10 @@ makeplot <- function(dataset, decorrelationmethod, color, nudge, dir) {
     superb(
             cbind(DV.1,DV.2,DV.3,DV.4,DV.5) ~ .,
             dataset, 
-            WSFactors = "Moment(5)",  
-            adjustments=list(purpose = "difference", decorrelation = decorrelationmethod), 
+            WSFactors   = "Moment(5)",  
+            adjustments = list(purpose = "difference", decorrelation = decorrelationmethod), 
             errorbarParams = list(color=color, width= 0.1, position = position_nudge(nudge), direction = dir ),
-            plotStyle="line" ) + 
+            plotLayout = "line" ) + 
         xlab("Moment") + ylab("Score") + 
         labs(subtitle=tlbl) +
         coord_cartesian( ylim = c(85,115) ) +
@@ -149,9 +149,9 @@ ggplot() +
 superb(
     cbind(pre, post) ~ ., 
     dataFigure2, 
-    WSFactors    = "Moment(2)", 
+    WSFactors   = "Moment(2)", 
     adjustments = list(purpose = "difference", decorrelation = "CM"), 
-    plotStyle   = "pointindividualline" ) + 
+    plotLayout  = "pointindividualline" ) + 
 xlab("Group") + ylab("Score") + 
 labs(subtitle="Correlation- and Difference-adjusted\n95% confidence intervals") +
 coord_cartesian( ylim = c(70,150) ) +
@@ -162,10 +162,10 @@ scale_x_discrete(labels=c("1" = "Collaborative games", "2" = "Unstructured activ
 superb(
     cbind(pre, post) ~ ., 
     dataFigure2, 
-    WSFactors    = "Moment(2)", 
+    WSFactors   = "Moment(2)", 
     adjustments = list(purpose = "difference", decorrelation = "CM"), 
-    plotStyle   = "corset",
-    lineParams = list(colorize=TRUE), 
+    plotLayout  = "corset",
+    lineParams = list(colorize="bySlope"), 
     violinParams = list(fill="green", alpha = .2)
 ) + 
 xlab("Group") + ylab("Score") + 
