@@ -14,7 +14,13 @@ library(foreign) # for read.spss
 library(stringr) # for str_remove_all and str_replace_all
 library(dplyr)
 
-appversion <- "App version 3.5; shipped with superb 0.95.13"
+appversion <- paste("App version 3.8; shipped with superb", packageVersion("superb"))
+
+# if additional directives were given to superbShiny(), retrieve them now
+initGR <- getOption("superb.shiny.GR")
+initGR <- if(!is.null(initGR)) {initGR} else {""}
+initGR <- gsub("+", "\n", initGR, fixed=TRUE) 
+
 
 ##########################################################
 ##########################################################
@@ -344,7 +350,12 @@ thePage <- fluidPage(
                     selectInput("superbPlotorder", "Select the order in which factors are plotted", 
                         multiple = TRUE, choices=c(""), selected="" ),
                     selectInput("superbLayout", "Select the plots' layout",
-                        choices=c("bar","point","line","lineBand","pointjitter","pointjitterviolin","pointindividualline","raincloud","halfwidthline","lineBand"),
+                        choices=c("line","bar","point",
+                                  "pointjitter","pointlinejitter",
+                                  "pointjitterviolin","pointindividualline",
+                                  "raincloud","halfwidthline","boxplot","lineBand","corset",
+                                  "circularpoint","circularline","circularpointjitter",
+                                  "circularpointlinejitter","circularlineBand"),
                         multiple = FALSE, selectize = FALSE),
                     strong("Specific graphic attributes (comma separated)"),br(),
                     div(style="display:inline-block", # if one choice is named, they must all be?
@@ -359,7 +370,10 @@ thePage <- fluidPage(
                     uiOutput("linedir3"),
                     uiOutput("linedir4"),
                     uiOutput("linedir5"),
-                    textAreaInput("ornates", "General graphic directives (one per line)", resize = "vertical"),
+                    textAreaInput("ornates", "General graphic directives (one per line)", 
+                        value = initGR,
+                        resize = "vertical"
+                    ),
                     bsButton("S5Prev", "Previous"),
                     bsButton("S5Apply", "Apply", disabled = FALSE),
                     bsButton("S5Next", "Next", disabled = TRUE),
@@ -597,9 +611,9 @@ generateScript <- function( cI ) {
         sep = "\n"
     )
 
-    # Step 5==script[3] ter: for plotStyle and factorOrder
-    plotlayout <- if (is.something(cI$Step2$plotStyle))
-        paste(indent1, "plotStyle = \"", cI$Step2$plotStyle, "\"", sep="")
+    # Step 5==script[3] ter: for plotLayout and factorOrder
+    plotlayout <- if (is.something(cI$Step2$plotLayout))
+        paste(indent1, "plotLayout = \"", cI$Step2$plotLayout, "\"", sep="")
     else NA
     factorord <-  if (is.something(cI$Step2$factorOrder))
         paste(indent1, "factorOrder = c(\"", paste(cI$Step2$factorOrder,collapse="\", \""), "\")", sep="")
@@ -646,6 +660,12 @@ runAndShowIt <- function( input, output, currentInfo) {
     params$adjustments <- currentInfo$Step4 # the adjustments are in a sub-list
     gattrib <- currentInfo$Step5            # the graphic attributes
     gdirect <- currentInfo$Step6            # the graphic directives
+    ### NEW 2025.05.25, version 0.95.99 ################
+    # retrieve any graphic directive(s) from superbShiny() if any
+    if (!is.something(gdirect)) {
+        if (!is.null(initGR)) {gdirect <- initGR}
+    }
+    ####################################################
 
     # in Step5, all the graphic attributes must be wrapped into lists...
     if (length(gattrib)!=0) {
@@ -672,9 +692,9 @@ runAndShowIt <- function( input, output, currentInfo) {
     resB <- cLogs(superbPlot, modifyList(params, list(showPlot=FALSE)))
 
     #if Step6 then
-    if (!is.null(currentInfo$Step6)) {
+    if (!is.null(gdirect)) {
         # listify the ornates
-        toto <- str_remove_all(currentInfo$Step6, "^[\r\n]|[\r\n]$")
+        toto <- str_remove_all(gdirect, "^[\r\n]|[\r\n]$")
         toto <- str_replace_all(toto,"\n",",\n")
             
         resC    <- cLogs(eval, list(str2lang(paste("list(",toto,"\n)"))))
@@ -859,7 +879,7 @@ theServerFct <- function(input, output, session) {
     info$Step2$statistic     <- "mean"          # changed on Step 3 
     info$Step2$errorbar      <- "CI"            # changed on Step 3 
     info$Step2$gamma         <- 0.95            # changed on Step 3 
-    info$Step2$plotStyle     <- NULL            # changed on Step 5
+    info$Step2$plotLayout    <- NULL            # changed on Step 5
     info$Step2$factorOrder   <- NULL            # changed on Step 5
     # ... the adjustments that are in Step4 (they will be sub-listed)...
     info$Step4$purpose       <- "single"        # changed on Step 4
@@ -1281,7 +1301,7 @@ theServerFct <- function(input, output, session) {
         } else {
             # collect information grabed on Step 5
             info$Step2$factorOrder   <<- input$superbPlotorder
-            info$Step2$plotStyle     <<- input$superbLayout
+            info$Step2$plotLayout    <<- input$superbLayout
 
             # reset the whole attributes
             info$Step5 <<- list()
