@@ -7,6 +7,42 @@ context("Testing GRD()")
 #################################################
 
 
+test_that("Instrument argument", {
+
+    old <- options()
+    on.exit(options(old))
+    options("superb.feedback" = "none")
+    
+    toto <- function(a,b,c) {
+        GRD( Instruments = list(precision = a, range = c(b, c)))
+    }
+    
+    expect_error( toto( "1", -Inf, +Inf) )
+    expect_error( toto(-0.1, -Inf, +Inf) )
+    expect_error( toto( 0.1, "-Inf", +Inf) )
+    expect_error( toto( 0.1, -Inf, "+Inf") )
+    expect_error( toto( 0.1, 10, 5) )
+    expect_error( toto( "1", -Inf, c(1,2) ) )
+    expect_error( toto( "1", c(1,2), +Inf) )
+    
+    # restores default information
+    options("superb.feedback" = c('design','warnings','summary'))    
+})
+
+test_that("subsidiary function", {
+
+    old <- options()
+    on.exit(options(old))
+    options("superb.feedback" = "none")
+    
+    expect_equal( length(reversed.expand.grid()), 0)
+    expect_equal( dim(reversed.expand.grid(a=1:2, b=1:3) ), c(6,2) )
+    expect_equal( dim(reversed.expand.grid( list(a=1:2, b=1:3) ) ), c(6,2) )
+
+    # restores default information
+    options("superb.feedback" = c('design','warnings','summary'))    
+})
+
 test_that("This is the minimum specification", {
 	old <- options() 
 	on.exit(options(old)) 
@@ -16,6 +52,7 @@ test_that("This is the minimum specification", {
     head(dta)
     tail(dta)
     expect_output( str(hist(dta$DV)), "List of 6" )
+
     # restores default information
     options("superb.feedback" = c('design','warnings','summary'))
 })
@@ -28,6 +65,9 @@ test_that("Renaming the dependant variable and setting the group size", {
 
     dta <- GRD( RenameDV = "score", SubjectsPerGroup = 200 )
     expect_output( str(hist(dta$score )), "List of 6" )
+    
+    expect_error(GRD(WSFactor = "test(2)", RenameDV = "test"))
+    
     # restores default information
     options("superb.feedback" = c('design','warnings','summary'))
 })
@@ -549,7 +589,7 @@ test_that("page 14", {
       SubjectsPerGroup = 200,
       Effects = list("Contrast" = extent(4) )
     )
-    library(lsr)
+    suppressWarnings(library(lsr))
     dta2 <- wideToLong(dta, within = c("Contrast"), sep = ".")
     plt <- histogram( ~DV | Contrast, data = dta2, 
       breaks = seq(min(dta$DV,-6)-1,max(dta$DV,6)+1, by=1), layout = c(3,1), aspect = 1,
